# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.tarfileUnsafeMembers

Module implementing checks for insecure use of 'tarfile.extracall()'.

### Global Attributes

None

### Classes

None

### Functions

_getMembersValue | Function to extract the value of the 'members' argument.
checkTarfileUnsafeMembers | Function to check for insecure use of 'tarfile.extracall()'.
getChecks | Public method to get a dictionary with checks handled by this module.

## _getMembersValue

_getMembersValue(context)

Function to extract the value of the 'members' argument.

context (SecurityContext)
  security context object

Return:
  dictionary containing the argument value

Return Type:
  dict

Up

## checkTarfileUnsafeMembers

checkTarfileUnsafeMembers(reportError, context, config)

Function to check for insecure use of 'tarfile.extracall()'.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up